pub struct BeamSpline { /* private fields */ }Expand description
ln φ(u), the logarithm of the beam per µs at flight time u, as a
uniform cubic B-spline in x = ln u over
knot_span_us. Faster than that span, ln φ
continues from the spline’s value and slope at the first knot with the
spline’s mean curvature over the span, so a beam whose curvature changes
across the span is continued with its mean; slower, the last interval’s
cubic continues. The curve is the beam only over the flight times a fit
integrates.
Implementations
Sourceimpl BeamSpline
impl BeamSpline
Sourcepub fn intervals(&self) -> usize
pub fn intervals(&self) -> usize
Number of spline intervals; there are three more coefficients.
Sourcepub fn coefficients(&self) -> &[f64]
pub fn coefficients(&self) -> &[f64]
The spline’s coefficients.
Sourcepub fn knot_span_us(&self) -> (f64, f64)
pub fn knot_span_us(&self) -> (f64, f64)
The flight times, in µs, the knots span.