pub struct Calibration {
pub t0_us: f64,
pub pulse: Arc<IkedaCarpenter>,
}Expand description
A neutron of flight time u arrives at t0_us + u plus a delay drawn from
pulse, whose flight path sets u for each energy.
Fields
t0_us: f64pulse: Arc<IkedaCarpenter>Trait Implementations
Sourceimpl Clone for Calibration
impl Clone for Calibration
Sourcefn clone(&self) -> Calibration
fn clone(&self) -> Calibration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for Calibration
impl RefUnwindSafe for Calibration
impl Send for Calibration
impl Sync for Calibration
impl Unpin for Calibration
impl UnsafeUnpin for Calibration
impl UnwindSafe for Calibration